Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(182)

Unified Diff: content/browser/geolocation/wifi_data_provider_linux_unittest.cc

Issue 2192683003: Revert of Reland: Geolocation: move from content/browser to device/ (patchset #2 id:20001 of https:… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2810
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/geolocation/wifi_data_provider_linux_unittest.cc
diff --git a/device/geolocation/wifi_data_provider_linux_unittest.cc b/content/browser/geolocation/wifi_data_provider_linux_unittest.cc
similarity index 97%
copy from device/geolocation/wifi_data_provider_linux_unittest.cc
copy to content/browser/geolocation/wifi_data_provider_linux_unittest.cc
index 85a47a49cb40a2075466fcde9566ea3b532c647c..1b73ef61748205408fc3d86e49f2ca6d030f267b 100644
--- a/device/geolocation/wifi_data_provider_linux_unittest.cc
+++ b/content/browser/geolocation/wifi_data_provider_linux_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "device/geolocation/wifi_data_provider_linux.h"
+#include "content/browser/geolocation/wifi_data_provider_linux.h"
#include <stdint.h>
@@ -10,8 +10,8 @@
#include "base/macros.h"
#include "base/memory/ref_counted.h"
-#include "base/message_loop/message_loop.h"
#include "base/strings/utf_string_conversions.h"
+#include "content/public/test/test_browser_thread_bundle.h"
#include "dbus/message.h"
#include "dbus/mock_bus.h"
#include "dbus/mock_object_proxy.h"
@@ -25,7 +25,7 @@ using ::testing::Invoke;
using ::testing::Return;
using ::testing::Unused;
-namespace device {
+namespace content {
class GeolocationWifiDataProviderLinuxTest : public testing::Test {
void SetUp() override {
@@ -106,9 +106,9 @@ class GeolocationWifiDataProviderLinuxTest : public testing::Test {
}
protected:
// WifiDataProvider requires a task runner to be present. The |message_loop_|
// is defined here, as it should outlive |wifi_provider_linux_|.
- base::MessageLoopForUI message_loop_;
+ TestBrowserThreadBundle thread_bundle_;
scoped_refptr<dbus::MockBus> mock_bus_;
scoped_refptr<dbus::MockObjectProxy> mock_network_manager_proxy_;
scoped_refptr<dbus::MockObjectProxy> mock_access_point_proxy_;
@@ -234,4 +234,4 @@ TEST_F(GeolocationWifiDataProviderLinuxTest, GetAccessPointData) {
EXPECT_EQ(4, access_point_data.channel);
}
-} // namespace device
+} // namespace content
« no previous file with comments | « content/browser/geolocation/wifi_data_provider_linux.cc ('k') | content/browser/geolocation/wifi_data_provider_mac.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -106,9 +106,9 @@ class GeolocationWifiDataProviderLinuxTest : public testing::Test {
}
protected:
- // WifiDataProvider requires a task runner to be present. The |message_loop_|
+ // WifiDataProvider requires a task runner to be present. The |thread_bundle_|
// is defined here, as it should outlive |wifi_provider_linux_|.
This is Rietveld 408576698